==> haskell-mysql-simple-0.4.9-39-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mysql-simple
version:              0.4.9
visibility:           public
id:                   mysql-simple-0.4.9-Cej34d5R5fyGlssYvugtKT
key:                  mysql-simple-0.4.9-Cej34d5R5fyGlssYvugtKT
license:              BSD-3-Clause
copyright:            2011 MailRank, Inc.
maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql-simple
synopsis:             A mid-level MySQL client library.
description:
    A mid-level client library for the MySQL database, intended to be
    fast and easy to use.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  a167c1df2f47be6f0f9c496e48458bbd
exposed:              True
exposed-modules:
    Database.MySQL.Simple Database.MySQL.Simple.Param
    Database.MySQL.Simple.QueryParams
    Database.MySQL.Simple.QueryResults Database.MySQL.Simple.Result
    Database.MySQL.Simple.Types

hidden-modules:       Database.MySQL.Internal.Blaze
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mysql-simple-0.4.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mysql-simple-0.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mysql-simple
hs-libraries:         HSmysql-simple-0.4.9-Cej34d5R5fyGlssYvugtKT
depends:
    attoparsec-0.14.4-HEPxPDNq5mJKRZZEtIXOMd base-4.16.4.0
    base16-bytestring-1.0.2.0-9AKEfJpeJHOK2mzYhoV7G4
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    containers-0.6.5.1 mysql-0.2.1-IrXPqgue2JoBbWQmnY52lg
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    pcre-light-0.4.1.2-3AK1ypQeFer442N3Z3HgOW text-1.2.5.0
    time-1.11.1.1 vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:
    /usr/share/doc/haskell-mysql-simple/html/mysql-simple.haddock

haddock-html:         /usr/share/doc/haskell-mysql-simple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mysql-simple-0.4.9-41-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mysql-simple
version:              0.4.9
visibility:           public
id:                   mysql-simple-0.4.9-5EYymc8LM1JKfhocJvdJXj
key:                  mysql-simple-0.4.9-5EYymc8LM1JKfhocJvdJXj
license:              BSD-3-Clause
copyright:            2011 MailRank, Inc.
maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql-simple
synopsis:             A mid-level MySQL client library.
description:
    A mid-level client library for the MySQL database, intended to be
    fast and easy to use.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  6a3d193ed266f9f02aba05c35a349eef
exposed:              True
exposed-modules:
    Database.MySQL.Simple Database.MySQL.Simple.Param
    Database.MySQL.Simple.QueryParams
    Database.MySQL.Simple.QueryResults Database.MySQL.Simple.Result
    Database.MySQL.Simple.Types

hidden-modules:       Database.MySQL.Internal.Blaze
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mysql-simple-0.4.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mysql-simple-0.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mysql-simple
hs-libraries:         HSmysql-simple-0.4.9-5EYymc8LM1JKfhocJvdJXj
depends:
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq base-4.16.4.0
    base16-bytestring-1.0.2.0-1EKQKfIbtqrKykCu8OdSyV
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    containers-0.6.5.1 mysql-0.2.1-E9mxp1dyMj5HSUkauSHb3Y
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    pcre-light-0.4.1.2-3AK1ypQeFer442N3Z3HgOW text-1.2.5.0
    time-1.11.1.1 vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-mysql-simple/html/mysql-simple.haddock

haddock-html:         /usr/share/doc/haskell-mysql-simple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
